@@ -2,7 +2,7 @@ package Redis::Fast;
 
 BEGIN {
     use XSLoader;
-    our $VERSION = '0.11';
+    our $VERSION = '0.12';
     XSLoader::load __PACKAGE__, $VERSION;
 }
 
@@ -407,10 +407,10 @@ Redis::Fast - Perl binding for Redis database
     ## Enable auto-reconnect
     ## Try to reconnect every 500ms up to 60 seconds until success
     ## Die if you can't after that
-    my $redis = Redis::Fast->new(reconnect => 60);
+    my $redis = Redis::Fast->new(reconnect => 60, every => 500_000);
 
-    ## Try each 100ms upto 2 seconds (every is in milisecs)
-    my $redis = Redis::Fast->new(reconnect => 2, every => 100);
+    ## Try each 100ms upto 2 seconds (every is in microseconds)
+    my $redis = Redis::Fast->new(reconnect => 2, every => 100_000);
 
     ## Disable the automatic utf8 encoding => much more performance
     ## !!!! This will be the default after 2.000, see ENCODING below
@@ -561,4 +561,9 @@ L<Redis.pm|https://github.com/melo/perl-redis>
 
 =back
 
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
 =cut
